==> payara-embedded-all-5.2020.4-sources.jar: fish/payara/microprofile/faulttolerance/policy/TimeoutPolicy.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2019 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.microprofile.faulttolerance.policy;

import java.lang.reflect.Method;
import java.time.Duration;
import java.time.temporal.ChronoUnit;

import javax.interceptor.InvocationContext;

import org.eclipse.microprofile.faulttolerance.Timeout;

import fish.payara.microprofile.faulttolerance.FaultToleranceConfig;

/**
 * The resolved "cached" information of a {@link Timeout} annotation an a specific method.
 * 
 * @author Jan Bernitt
 */
public final class TimeoutPolicy extends Policy {

    public final long value;
    public final ChronoUnit unit;

    public TimeoutPolicy(Method annotatedMethod, long value, ChronoUnit unit) {
        checkAtLeast(0, annotatedMethod, Timeout.class, "value", value);
        this.value = value;
        this.unit = unit;
    }

    public static TimeoutPolicy create(InvocationContext context, FaultToleranceConfig config) {
        if (config.isAnnotationPresent(Timeout.class) && config.isEnabled(Timeout.class)) {
            Timeout annotation = config.getAnnotation(Timeout.class);
            return new TimeoutPolicy(context.getMethod(),
                    config.value(annotation),
                    config.unit(annotation));
        }
        return null;
    }

    public long toMillis() {
        return Duration.of(value, unit).toMillis();
    }
}

==> payara-embedded-all-6.2023.10-sources.jar: fish/payara/microprofile/faulttolerance/policy/TimeoutPolicy.java <==
/*
 * DO NOT ALTER OR REMOVE COPYRIGHT NOTICES OR THIS HEADER.
 *
 * Copyright (c) 2019-2021 Payara Foundation and/or its affiliates. All rights reserved.
 *
 * The contents of this file are subject to the terms of either the GNU
 * General Public License Version 2 only ("GPL") or the Common Development
 * and Distribution License("CDDL") (collectively, the "License").  You
 * may not use this file except in compliance with the License.  You can
 * obtain a copy of the License at
 * https://github.com/payara/Payara/blob/master/LICENSE.txt
 * See the License for the specific
 * language governing permissions and limitations under the License.
 *
 * When distributing the software, include this License Header Notice in each
 * file and include the License file at glassfish/legal/LICENSE.txt.
 *
 * GPL Classpath Exception:
 * The Payara Foundation designates this particular file as subject to the "Classpath"
 * exception as provided by the Payara Foundation in the GPL Version 2 section of the License
 * file that accompanied this code.
 *
 * Modifications:
 * If applicable, add the following below the License Header, with the fields
 * enclosed by brackets [] replaced by your own identifying information:
 * "Portions Copyright [year] [name of copyright owner]"
 *
 * Contributor(s):
 * If you wish your version of this file to be governed by only the CDDL or
 * only the GPL Version 2, indicate your decision by adding "[Contributor]
 * elects to include this software in this distribution under the [CDDL or GPL
 * Version 2] license."  If you don't indicate a single choice of license, a
 * recipient has the option to distribute your version of this file under
 * either the CDDL, the GPL Version 2 or to extend the choice of license to
 * its licensees as provided above.  However, if you add GPL Version 2 code
 * and therefore, elected the GPL Version 2 license, then the option applies
 * only if the new code is made subject to such option by the copyright
 * holder.
 */
package fish.payara.microprofile.faulttolerance.policy;

import java.lang.reflect.Method;
import java.time.Duration;
import java.time.temporal.ChronoUnit;

import jakarta.interceptor.InvocationContext;

import org.eclipse.microprofile.faulttolerance.Timeout;

import fish.payara.microprofile.faulttolerance.FaultToleranceConfig;

/**
 * The resolved "cached" information of a {@link Timeout} annotation an a specific method.
 * 
 * @author Jan Bernitt
 */
public final class TimeoutPolicy extends Policy {

    public final long value;
    public final ChronoUnit unit;

    public TimeoutPolicy(Method annotatedMethod, long value, ChronoUnit unit) {
        checkAtLeast(0, annotatedMethod, Timeout.class, "value", value);
        this.value = value;
        this.unit = unit;
    }

    public static TimeoutPolicy create(InvocationContext context, FaultToleranceConfig config) {
        if (config.isAnnotationPresent(Timeout.class) && config.isEnabled(Timeout.class)) {
            Timeout annotation = config.getAnnotation(Timeout.class);
            return new TimeoutPolicy(context.getMethod(),
                    config.value(annotation),
                    config.unit(annotation));
        }
        return null;
    }

    public long toMillis() {
        return Duration.of(value, unit).toMillis();
    }
}
